<template>
  <div class="app-container">
    <el-card class="box-card" >
      <el-form :model="queryParams" ref="queryForm" :inline="true"  v-show="showSearch" label-width="68px" >
        <el-form-item label-width="120" label="箱体编码:" prop="sfcCode">
          <el-input clearable
                    v-model="queryParams.sfcCode"
                    placeholder="请输入箱体编码"
                    @keyup.enter.native="handleQuery"/>
        </el-form-item>
        <el-form-item label-width="120" label="工位号:" prop="locationCode">
          <el-input clearable
                    v-model="queryParams.locationCode"
                    placeholder="请输入工位号"
                    @keyup.enter.native="handleQuery"/>
        </el-form-item>
        <el-form-item label-width="130" label="保存日期" prop="dateConditions">
          <el-date-picker
            v-model="queryParams.dateConditions"
            type="datetimerange"
            :picker-options="pickerOptions"
            value-format="yyyy-MM-dd HH:mm:ss"
            range-separator="至"
            start-placeholder="开始日期"
            end-placeholder="结束日期"
            align="right">
          </el-date-picker>
        </el-form-item>
        <el-form-item style="float: right">
          <el-button type="primary" icon="el-icon-refresh" @click="handleQuery">查询</el-button>
          <el-button type=""    icon="el-icon-refresh"  @click="resetQuery">重置</el-button>
        </el-form-item>
      </el-form>
    </el-card> <el-card style="margin-top: 10px" class="box-card">
    <el-table v-loading="loading" border :data="refuelDataReportList" @selection-change="handleSelectionChange" v-if="refuelDataReportList.length > 0">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="箱体编码" align="center" width="200" prop="sfcCode"></el-table-column>
      <el-table-column label="工位" align="center" prop="locationCode"></el-table-column>
      <el-table-column label="参数名称" align="center" prop="paramName"></el-table-column>
      <el-table-column label="参数编码" align="center" prop="paramCode"></el-table-column>
      <el-table-column label="参数值" align="center" prop="paramValue"></el-table-column>
      <el-table-column label="单位" align="center" prop="unit"></el-table-column>
      <el-table-column label="结果" align="center" prop="state"></el-table-column>
      <el-table-column label="采集时间" align="center" prop="collectionTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.collectionTime, '{y}-{m}-{d} {h}:{i}:{s}') }}</span>
        </template>
      </el-table-column>
    </el-table>
    <el-empty v-else>
      <span slot="description">暂无数据</span>
    </el-empty>
  </el-card>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

  </div>
</template>
<script>

import { listParamCollection, getParamCollection, delParamCollection, addParamCollection, updateParamCollection } from "@/api/main/da/paramCollection/paramCollection";

export default {
  name: "refuelData",
  computed: {
  },
  dicts: ['sys_normal_disable','order_scheduling_produce_status','print_status'],
  components: {
  },
  data(){
    return{
      dateRange: '',
      // 用于存储选择的日期范围
      total: 0,
      ids: [],
      refuelDataReportList: [],
      loading: true,
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        workOrderNo: null,
        sfcCode: null,
        productCode: null,
        productionLine: null,
        locationCode: null,
        equipmentNo: null,
        paramCode: null,
        paramValue: null,
        paramUpper: null,
        paramLower: null,
        paramStandard: null,
        collectionTime: null,
        spareField1: null,
        spareField2: null,
        createUser: null,
        createTime: null,
        updateUser: null,
        updateTime: null,
        state: null,
        paramName: null,
        unit: null,
        type: '机油加注数据',
        startDate: null,
        endDate: null,
        dateConditions: [],
      },
      pickerOptions: {
        shortcuts: [{
          text: '最近一周',
          onClick(picker) {
            const end = new Date();
            const start = new Date();
            start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
            picker.$emit('pick', [start, end]);
          }
        }, {
          text: '最近一个月',
          onClick(picker) {
            const end = new Date();
            const start = new Date();
            start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
            picker.$emit('pick', [start, end]);
          }
        }, {
          text: '最近三个月',
          onClick(picker) {
            const end = new Date();
            const start = new Date();
            start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
            picker.$emit('pick', [start, end]);
          }
        }]
      },
    }
  },
  created() {
    this.getList();
  },
  methods: {

    reset() {
      this.form = {
        id: null,
        workOrderNo: null,
        sfcCode: null,
        productCode: null,
        productionLine: null,
        locationCode: null,
        equipmentNo: null,
        paramCode: null,
        paramValue: null,
        paramUpper: null,
        paramLower: null,
        paramStandard: null,
        collectionTime: null,
        spareField1: null,
        spareField2: null,
        createUser: null,
        createTime: null,
        updateUser: null,
        updateTime: null,
        state: null,
        paramName: null,
        unit: null,
        type: '机油加注数据',
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },

    getList() {
      this.loading = true;
      listParamCollection(this.queryParams).then(response => {
        this.refuelDataReportList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },

  },
}

</script>

<style scoped>
::v-deep .el-form-item__label{
  font-size: large;
}
::v-deep .el-card__body{
  padding: 15px 20px 0px 20px;
}
</style>
